==> haskell-base-unicode-symbols-0.2.2.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.2.4
id: base-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
key: base-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
license: BSD-3-Clause
copyright: 2009–2011 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
author: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension \[1\]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1\] <http://www.haskell.org/ghc/docs/latest/html/users_guide/syntax-extns.html#unicode-syntax>
abi: 366e560eb7f3404f11174470b2f37ce4
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Prelude.Unicode
import-dirs: /usr/lib/ghc-8.6.2/site-local/base-unicode-symbols-0.2.2.4
library-dirs: /usr/lib/ghc-8.6.2/site-local/base-unicode-symbols-0.2.2.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/base-unicode-symbols-0.2.2.4
hs-libraries: HSbase-unicode-symbols-0.2.2.4-A4I8mYzRSE3gt3LBeWhol
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base-unicode-symbols-0.2.3-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-base-unicode-symbols.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base-unicode-symbols
version: 0.2.3
id: base-unicode-symbols-0.2.3-DSwrVFFd7W25G8H5XUgcPz
key: base-unicode-symbols-0.2.3-DSwrVFFd7W25G8H5XUgcPz
license: BSD-3-Clause
copyright: 2009–2018 Roel van Dijk <vandijk.roel@gmail.com>
maintainer: Roel van Dijk <vandijk.roel@gmail.com>
author: Roel van Dijk <vandijk.roel@gmail.com>
stability: provisional
homepage: http://haskell.org/haskellwiki/Unicode-symbols
synopsis: Unicode alternatives for common functions and operators
description:
    This package defines new symbols for a number of functions,
    operators and types in the base package.
    .
    All symbols are documented with their actual definition and
    information regarding their Unicode code point. They should be
    completely interchangeable with their definitions.
    .
    For further Unicode goodness you can enable the @UnicodeSyntax@
    language extension [1]. This extension enables Unicode characters
    to be used to stand for certain ASCII character sequences,
    i.e. &#x2192; instead of @->@, &#x2200; instead of @forall@ and many
    others.
    .
    Original idea by P&#xE9;ter Divi&#xE1;nszky.
    .
    \[1] <https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/glasgow_exts.html#unicode-syntax>
abi: 3e08d2b806c1808a3d818aca7ed4489f
exposed: True
exposed-modules:
    Control.Applicative.Unicode Control.Arrow.Unicode
    Control.Category.Unicode Control.Monad.Unicode Data.Bool.Unicode
    Data.Eq.Unicode Data.Foldable.Unicode Data.Function.Unicode
    Data.List.Unicode Data.Monoid.Unicode Data.Ord.Unicode
    Data.String.Unicode Numeric.Natural.Unicode Prelude.Unicode
import-dirs: /usr/lib/ghc-8.6.3/site-local/base-unicode-symbols-0.2.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/base-unicode-symbols-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/base-unicode-symbols-0.2.3
hs-libraries: HSbase-unicode-symbols-0.2.3-DSwrVFFd7W25G8H5XUgcPz
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-base-unicode-symbols/html/base-unicode-symbols.haddock
haddock-html: /usr/share/doc/haskell-base-unicode-symbols/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
